@@ -38,13 +38,14 @@
 #include <glib.h>
 #include <glib/goption.h>
 #include <glib/gstdio.h>
-#include "gnome-i18nP.h"
 
+#include "gnome-i18n.h"
 #include "gnome-init.h"
 #include "gnome-gconfP.h"
 #include "gnome-util.h"
 #include "gnome-sound.h"
 #include "gnome-triggers.h"
+#include "libgnome-private.h"
 
 #include <bonobo-activation/bonobo-activation.h>
 #include <bonobo-activation/bonobo-activation-version.h>
@@ -52,7 +53,8 @@
 
 #include <libgnomevfs/gnome-vfs-init.h>
 
-#include "libgnome-private.h"
+/* implemented in gnome-sound.c */
+G_GNUC_INTERNAL extern void _gnome_sound_set_enabled (gboolean);
 
 /*****************************************************************************
  * bonobo
@@ -336,6 +338,8 @@ safe_mkdir (const char *pathname, mode_t mode)
 static void
 libgnome_userdir_setup (gboolean create_dirs)
 {
+	struct stat statbuf;
+	
 	if(!gnome_user_dir) {
                 const char *override;
 
@@ -352,11 +356,7 @@ libgnome_userdir_setup (gboolean create_dirs)
 
                         /* chop trailing slash */
                         len = strlen (gnome_user_dir);
-                        if (len > 1 && (gnome_user_dir[len-1] == G_DIR_SEPARATOR
-#ifdef G_OS_WIN32
-					|| gnome_user_dir[len-1] == '/'
-#endif
-					))
+                        if (len > 1 && G_IS_DIR_SEPARATOR (gnome_user_dir[len - 1]))
                                 gnome_user_dir[len - 1] = '\0';
 
                         gnome_user_private_dir = g_strconcat (gnome_user_dir,
@@ -399,8 +399,15 @@ libgnome_userdir_setup (gboolean create_dirs)
 	}
 
 
+       if (g_stat (gnome_user_private_dir, &statbuf) < 0) {
+               g_printerr (_("Could not stat private per-user gnome configuration directory `%s': %s\n"),
+                       gnome_user_private_dir, strerror(errno));
+               exit(1);
+       }
+
 	/* change mode to 0700 on the private directory */
-	if (g_chmod (gnome_user_private_dir, 0700) < 0) {
+	if (((statbuf.st_mode & 0700) != 0700 )  &&
+            g_chmod (gnome_user_private_dir, 0700) < 0) {
 		g_printerr (_("Could not set mode 0700 on private per-user gnome configuration directory `%s': %s\n"),
 			gnome_user_private_dir, strerror(errno));
 		exit(1);
@@ -419,79 +426,23 @@ static void
 libgnome_post_args_parse (GnomeProgram *program,
 			  GnomeModuleInfo *mod_info)
 {
-	GValue value = { 0 };
-	gboolean enable_val = TRUE, create_dirs_val = TRUE;
-	char *espeaker_val = NULL;
+        gboolean enable_sound = TRUE, create_dirs = TRUE;
+        char *espeaker = NULL;
 
-	g_value_init (&value, G_TYPE_BOOLEAN);
-	g_object_get_property (G_OBJECT (program),
-			       GNOME_PARAM_CREATE_DIRECTORIES,
-			       &value);
-	create_dirs_val = g_value_get_boolean (&value);
-	g_value_unset (&value);
+        g_object_get (program,
+                      GNOME_PARAM_CREATE_DIRECTORIES, &create_dirs,
+                      GNOME_PARAM_ENABLE_SOUND, &enable_sound,
+                      GNOME_PARAM_ESPEAKER, &espeaker,
+                      NULL);
 
-	g_value_init (&value, G_TYPE_BOOLEAN);
-	g_object_get_property (G_OBJECT (program),
-			       GNOME_PARAM_ENABLE_SOUND, &value);
-	enable_val = g_value_get_boolean (&value);
-	g_value_unset (&value);
+        gnome_sound_init (espeaker);
+        g_free (espeaker);
 
-	g_value_init (&value, G_TYPE_STRING);
-	g_object_get_property (G_OBJECT (program),
-			       GNOME_PARAM_ESPEAKER, &value);
-	espeaker_val = g_value_dup_string (&value);
-	g_value_unset (&value);
-
-
-	if (enable_val) {
-		gnome_sound_init(espeaker_val);
-	}
-
-	libgnome_userdir_setup (create_dirs_val);
+        _gnome_sound_set_enabled (enable_sound);
 
+        libgnome_userdir_setup (create_dirs);
 }
 
-static struct poptOption gnomelib_options [] = {
-	{ NULL, '\0', POPT_ARG_INTL_DOMAIN, GETTEXT_PACKAGE, 0, NULL, NULL},
-
-	{ NULL, '\0', POPT_ARG_CALLBACK, (void *) libgnome_option_cb, 0, NULL, NULL},
-
-	{ "disable-sound", '\0', POPT_ARG_NONE,
-	  NULL, ARG_DISABLE_SOUND, N_("Disable sound server usage"), NULL},
-
-	{ "enable-sound", '\0', POPT_ARG_NONE,
-	  NULL, ARG_ENABLE_SOUND, N_("Enable sound server usage"), NULL},
-
-	{ "espeaker", '\0', POPT_ARG_STRING,
-	  NULL, ARG_ESPEAKER, N_("Host:port on which the sound server to use is"
-				 " running"),
-	  N_("HOSTNAME:PORT")},
-
-	{"version", '\0', POPT_ARG_NONE,
-	 NULL, ARG_VERSION, VERSION, NULL},
-
-	{ NULL, '\0', 0,
-	  NULL, 0 , NULL, NULL}
-};
-
-static const GOptionEntry gnomelib_goptions [] = {
-	{ "disable-sound", '\0', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK,
-	  libgnome_goption_disable_sound, N_("Disable sound server usage"), NULL },
-
-	{ "enable-sound", '\0', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK,
-	  libgnome_goption_enable_sound, N_("Enable sound server usage"), NULL },
-
-	{ "espeaker", '\0',0, G_OPTION_ARG_CALLBACK,
-	  libgnome_goption_epeaker,
-	  N_("Host:port on which the sound server to use is running"),
-	  N_("HOSTNAME:PORT") },
-
-	{ "version", '\0', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK,
-	  (GOptionArgFunc) libgnome_goption_version, VERSION, NULL },
-
-	{ NULL }
-};
-
 static void
 gnome_vfs_post_args_parse (GnomeProgram *program, GnomeModuleInfo *mod_info)
 {
@@ -519,6 +470,23 @@ static GOptionGroup *
 libgnome_module_get_goption_group (void)
 {
 	GOptionGroup *option_group;
+	const GOptionEntry gnomelib_goptions [] = {
+		{ "disable-sound", '\0', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK,
+		  libgnome_goption_disable_sound, N_("Disable sound server usage"), NULL },
+
+		{ "enable-sound", '\0', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK,
+		  libgnome_goption_enable_sound, N_("Enable sound server usage"), NULL },
+
+		{ "espeaker", '\0',0, G_OPTION_ARG_CALLBACK,
+		  libgnome_goption_epeaker,
+		  N_("Host:port on which the sound server to use is running"),
+		  N_("HOSTNAME:PORT") },
+
+		{ "version", '\0', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK,
+		  (GOptionArgFunc) libgnome_goption_version, NULL, NULL },
+
+		{ NULL }
+	};
 
 	option_group = g_option_group_new ("gnome",
 					   N_("GNOME Library"),
@@ -541,6 +509,29 @@ libgnome_module_get_goption_group (void)
 const GnomeModuleInfo *
 libgnome_module_info_get (void)
 {
+	static const struct poptOption gnomelib_options [] = {
+		{ NULL, '\0', POPT_ARG_INTL_DOMAIN, GETTEXT_PACKAGE, 0, NULL, NULL},
+
+		{ NULL, '\0', POPT_ARG_CALLBACK, (void *) libgnome_option_cb, 0, NULL, NULL},
+
+		{ "disable-sound", '\0', POPT_ARG_NONE,
+		  NULL, ARG_DISABLE_SOUND, N_("Disable sound server usage"), NULL},
+
+		{ "enable-sound", '\0', POPT_ARG_NONE,
+		  NULL, ARG_ENABLE_SOUND, N_("Enable sound server usage"), NULL},
+
+		{ "espeaker", '\0', POPT_ARG_STRING,
+		  NULL, ARG_ESPEAKER, N_("Host:port on which the sound server to use is"
+					" running"),
+		N_("HOSTNAME:PORT")},
+
+		{ "version", '\0', POPT_ARG_NONE,
+		  NULL, ARG_VERSION, VERSION, NULL},
+
+		{ NULL, '\0', 0,
+		  NULL, 0 , NULL, NULL}
+	};
+
 	static GnomeModuleInfo module_info = {
 		"libgnome", VERSION, N_("GNOME Library"),
 		NULL, NULL,
